@@ -9,7 +9,7 @@ function i18n($value) {
 $skip_errors = false; // We need to hide a couple of unsightly errors even here...
 function log_setup_error($errno , $errstr , $errfile , $errline) {
   global $skip_errors;
-  if ( $skip_errors ) return; 
+  if ( $skip_errors ) return;
   error_log('DAViCal setup.php: Informational: '.$errfile.'('.$errline.'): ['.$errno.'] '.$errstr);
 }
 
@@ -51,13 +51,13 @@ class CheckResult {
   private $ok;
   private $use_class;
   private $description;
-  
+
   function __construct( $success, $description=null, $use_class=null ) {
     $this->ok = (boolean) $success;
     $this->description = (isset($description)?$description : ($success===true? i18n('Passed') : i18n('Fail')));
-    $this->use_class = (isset($use_class)?$use_class:($success===true?'dep_ok' : 'dep_fail'));        
+    $this->use_class = (isset($use_class)?$use_class:($success===true?'dep_ok' : 'dep_fail'));
   }
-  
+
   public function getClass() {
     return $this->use_class;
   }
@@ -169,7 +169,7 @@ $loaded_extensions = array_flip(get_loaded_extensions());
 
 
 function do_error( $errormessage ) {
-  // We can't translate this because we're testing these things even before 
+  // We can't translate this because we're testing these things even before
   // the translation interface is available...
   printf("<p class='error'><br/>%s</p>", $errormessage );
 }
@@ -185,7 +185,7 @@ function get_phpinfo() {
   phpinfo();
   $phpinfo = ob_get_contents( );
   ob_end_clean( );
-  
+
   $phpinfo = preg_replace( '{^.*?<body>}s', '', $phpinfo);
   $phpinfo = preg_replace( '{</body>.*?$}s', '', $phpinfo);
   return $phpinfo;
@@ -201,12 +201,12 @@ try {
   }
 }
 catch( Exception $e ) {
-  class FakeSession {
+  class setupFakeSession {
     function AllowedTo() {
       return true;
     }
   }
-  $session = new FakeSession(1);
+  $session = new setupFakeSession(1);
 }
 
 
@@ -224,6 +224,10 @@ function check_datetime() {
   return $result;
 }
 
+function check_xml() {
+  return new CheckResult(function_exists('xml_parser_create_ns'));
+}
+
 function check_schema_version() {
   global $c;
   if ( $c->want_dbversion[0] == $c->schema_major
@@ -248,7 +252,9 @@ function check_schema_version() {
 
 function check_davical_version() {
   global $c;
-  $url = 'http://www.davical.org/current_davical_version?v='.$c->version_string;
+  if ( ! ini_get('allow_url_fopen') )
+    return new CheckResult( false, translate("Cannot determine upstream version, because PHP has set “<a href=\"https://secure.php.net/manual/en/filesystem.configuration.php#ini.allow-url-fopen\"><code>allow_url_fopen</code></a>” to “<code>FALSE</code>”."), 'dep_warning' );
+  $url = 'https://www.davical.org/current_davical_version?v='.$c->version_string;
   $version_file = @fopen($url, 'r');
   if ( ! $version_file ) return new CheckResult( false, translate("Could not retrieve") . " '$url'", 'dep_warning' );
   $current_version = htmlentities( trim(fread( $version_file,12)) );
@@ -269,16 +275,16 @@ function check_davical_version() {
 
 function check_awl_version() {
   global $c;
-  
+
   if ( !function_exists('awl_version') ) return new CheckResult(false);
-  
+
   $result = new CheckResult($c->want_awl_version == awl_version());
   if ( ! $result->getOK() ) {
     $result->setDescription( sprintf(i18n('Want: %s, Currently: %s'), $c->want_awl_version, awl_version()) );
     if ( $c->want_awl_version < awl_version() ) $result->setClass('dep_warning');
   }
   return $result;
-  
+
 }
 
 
@@ -312,7 +318,7 @@ EOTABLE;
 
 function build_dependencies_table( ) {
   global $c;
-  
+
   $dependencies = array(
     translate('Current DAViCal version ')         => 'check_davical_version',
     translate('AWL Library version ')             => 'check_awl_version',
@@ -324,6 +330,7 @@ function build_dependencies_table( ) {
     translate('GNU gettext support')              => 'check_gettext',
     translate('PHP iconv support')                => 'check_iconv',
     translate('PHP DateTime class')               => 'check_datetime',
+    translate('PHP XML support')                  => 'check_xml',
     translate('Suhosin "server.strip" disabled')  => 'check_suhosin_server_strip',
     translate('PHP Magic Quotes GPC off')         => 'check_magic_quotes_gpc',
     translate('PHP Magic Quotes runtime off')     => 'check_magic_quotes_runtime',
@@ -335,8 +342,8 @@ function build_dependencies_table( ) {
     $dependencies[translate('PHP LDAP module available')] = 'check_ldap';
   }
 
-  $translated_failure_code = translate('<a href="http://wiki.davical.org/w/Setup_Failure_Codes/%s">Explanation on DAViCal Wiki</a>');
-    
+  $translated_failure_code = translate('<a href="https://wiki.davical.org/w/Setup_Failure_Codes/%s">Explanation on DAViCal Wiki</a>');
+
   $dependencies_table = '';
   $dep_tpl = '<tr class="%s">
   <td>%s</td>
@@ -352,7 +359,7 @@ function build_dependencies_table( ) {
                              rawurlencode($k)
                            );
   }
-  
+
   return $dependencies_table;
 }
 
@@ -395,7 +402,7 @@ $heading_php_info = translate('PHP Information');
 
 // Translations shared with index.php
 $heading_clients = translate('Configuring Calendar Clients for DAViCal');
-$content_cli1 = translate('The <a href="http://www.davical.org/clients.php">client setup page on the DAViCal website</a> has information on how to configure Evolution, Sunbird, Lightning and Mulberry to use remotely hosted calendars.');
+$content_cli1 = translate('The <a href="https://www.davical.org/clients.php">client setup page on the DAViCal website</a> has information on how to configure Evolution, Sunbird, Lightning and Mulberry to use remotely hosted calendars.');
 $content_cli2 = translate('The administrative interface has no facility for viewing or modifying calendar data.');
 
 // Translations shared with index.php
@@ -405,7 +412,7 @@ $content_config2 = ( $config_warnings == '' ? '' : '<div class="error"><h3 class
              . translate('Your configuration produced PHP errors which should be corrected') . '</h3><pre>'
              . $config_warnings.'</pre></div>'
           );
-$content_config3 = translate('The <a href="http://www.davical.org/installation.php">DAViCal installation page</a> on the DAViCal website has some further information on how to install and configure this application.');
+$content_config3 = translate('The <a href="https://www.davical.org/installation.php">DAViCal installation page</a> on the DAViCal website has some further information on how to install and configure this application.');
 
 
   echo <<<EOBODY
