@@ -34,8 +34,7 @@ $editor->AddAttribute('mode', 'id', 'fld_mode');
 $editor->SetWhere( 'collection_id='.$id );
 
 $privilege_names = array( 'read', 'write-properties', 'write-content', 'unlock', 'read-acl', 'read-current-user-privilege-set',
-                         'bind', 'unbind', 'write-acl', 'read-free-busy', 'schedule-deliver-invite', 'schedule-deliver-reply',
-                         'schedule-query-freebusy', 'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );
+                          'bind', 'unbind', 'write-acl', 'read-free-busy' );
 
 $params = array(
   ':session_principal' => $session->principal_id,
@@ -91,9 +90,9 @@ if ( $can_write_collection && $editor->IsSubmit() ) {
     $c->messages[] = i18n("Creating new Collection.");
   }
   else {
-    $c->messages[] = i18n("Updating Collection record.");
+    $c->messages[] = i18n("Updating Collection.");
   }
-  if ( !$editor->Write() ) { 
+  if ( !$editor->Write() ) {
     $c->messages[] = i18n("Failed to write collection.");
     if ( $id > 0 ) $editor->GetRecord();
   }
@@ -129,7 +128,7 @@ if ( $can_write_collection && $editor->IsSubmit() ) {
 else {
   if ( $id > 0 ) $editor->GetRecord();
   if ( $editor->IsSubmit() ) {
-    $c->messages[] = i18n('You do not have permission to modify this record.');
+    $c->messages[] = i18n('You do not have permission to modify this collection.');
   }
 }
 if ( $editor->Available() ) {
@@ -137,14 +136,15 @@ if ( $editor->Available() ) {
   $entryqry = new AwlQuery( 'SELECT count(*) as count from caldav_data where collection_id='.$editor->Value('collection_id')  );
   $entryqry->Exec('admin-collection-edit');
   $entries = $entryqry->Fetch();  $entries = $entries->count;
-  
-  $externalqry = new AwlQuery( 'SELECT external_url from dav_binding where bound_source_id=:id  limit 1', array(':id' => $editor->Value('collection_id') ) );
-  $externalqry->Exec('external-bind-url');
-  $external = $externalqry->Fetch();  $external_url = $external->external_url;
-  if ( $external_url ) {
-    $external_bind = "\n<tr> <th class='right'>" . translate('External Url') . "</th>         <td class='left'>$external_url</td> </tr>";
-  } else {
-    $external_bind = "";
+
+  $external_bind = "";
+  if ($can_write_collection) {
+    $externalqry = new AwlQuery( 'SELECT external_url from dav_binding where bound_source_id=:id  limit 1', array(':id' => $editor->Value('collection_id') ) );
+    $externalqry->Exec('external-bind-url');
+    $external = $externalqry->Fetch();  $external_url = $external->external_url;
+    if ( $external_url ) {
+        $external_bind = "\n<tr> <th class='right'>" . translate('External Url') . "</th>         <td class='left'>$external_url</td> </tr>";
+    }
   }
 }
 else {
@@ -182,7 +182,7 @@ $privilege_xlate = array(
 );
 
 /**
-* privilege_format_function is for formatting the binary privileges from the
+* collection_privilege_format_function is for formatting the binary privileges from the
 * database, including localising them.  This is a hook function for a browser
 * column object, so it takes three parameters:
 * @param mixed $value The value of the column.
@@ -190,13 +190,13 @@ $privilege_xlate = array(
 * @param dbrow $row The row object we read from the database.
 * @return string The formatted privileges.
 */
-function privilege_format_function( $value, $column, $row ) {
+function collection_privilege_format_function( $value, $column, $row ) {
   global $privilege_xlate;
 
-  $privs = bits_to_privilege($value);
+  $privs = bits_to_privilege($value, 'calendar');
   $formatted = '';
   foreach( $privs AS $k => $v ) {
-    $formatted .= ($formatted == '' ? '' : ' , ');
+    $formatted .= ($formatted == '' ? '' : ', ');
     $v = preg_replace( '{^.*:}', '', $v );
     $formatted .= (isset($privilege_xlate[$v]) ? $privilege_xlate[$v] : $v );
   }
@@ -218,6 +218,11 @@ $value_dav_name = $c->base_url.'/caldav.php'. ( $editor->Available() ? '##dav_na
 $prompt_load_file = translate('Load From File');
 $prompt_displayname = translate('Displayname');
 $prompt_entries = translate('Items in Collection');
+if ( $entries > 0 && $editor->Value('is_calendar') && isset($c->get_includes_subcollections) && $c->get_includes_subcollections
+  && ( bindec($permissions->priv) & privilege_to_bits( array('urn:ietf:params:xml:ns:caldav:read-free-busy','DAV::read')))) {
+  $entries = '<a href="' . $c->base_url . '/caldav.php' . substr($editor->Value('dav_name'), 0, -1) . '.ics" title="'
+    . translate('Download entire collection as .ics file') . '">' . $entries . '</a>';
+}
 $prompt_public = translate('Publicly Readable');
 $prompt_calendar = translate('Is a Calendar');
 $prompt_addressbook = translate('Is an Addressbook');
@@ -234,6 +239,25 @@ $btn_fb = htmlspecialchars(translate('Free/Busy'));        $btn_fb_title = htmls
 $btn_sd = htmlspecialchars(translate('Schedule Deliver')); $btn_sd_title = htmlspecialchars(translate('Privileges to allow delivery of scheduling messages'));
 $btn_ss = htmlspecialchars(translate('Schedule Send'));    $btn_ss_title = htmlspecialchars(translate('Privileges to delegate scheduling decisions'));
 
+if ($can_write_collection || ! $id > 0) {
+  $privileges_row = <<<EOPRIV
+<input type="button" value="$btn_all" class="submit" title="$btn_all_title" onclick="toggle_privileges('default_privileges', 'all', 'form_editor_1');">
+<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title"
+ onclick="toggle_privileges('default_privileges', 'read', 'write-properties', 'write-content', 'bind', 'unbind', 'read-free-busy',
+                            'read-current-user-privilege-set', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy',
+                            'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
+<input type="button" value="$btn_read" class="submit" title="$btn_read_title"
+ onclick="toggle_privileges('default_privileges', 'read', 'read-free-busy', 'schedule-query-freebusy', 'read-current-user-privilege-set' );">
+<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title"
+ onclick="toggle_privileges('default_privileges', 'read-free-busy', 'schedule-query-freebusy' );">
+<br>$privileges_set
+EOPRIV;
+  $submit_row = '<tr> <th class="right"></th>                   <td class="left" colspan="2">##submit##</td> </tr>';
+} else {
+  $privileges_row = collection_privilege_format_function( $editor->Value('default_privileges') );
+  $privileges_row = '<div id="privileges">' . $privileges_row . '</div>';
+  $submit_row = '';
+}
 
 $id = $editor->Value('collection_id');
 $template = <<<EOTEMPLATE
@@ -332,31 +356,19 @@ label.privilege {
  <tr> <th class="right">$prompt_dav_name:</th>         <td class="left">$value_dav_name</td> </tr>$external_bind
  <tr> <th class="right">$prompt_entries:</th>          <td class="left">$entries</td> </tr>
  <tr> <th class="right">$prompt_load_file:</th>        <td class="left">##ics_file.file.60## ##mode.checkbox##
- </td> </tr> 
+ </td> </tr>
  <tr> <th class="right">$prompt_displayname:</th>      <td class="left">##dav_displayname.input.50##</td> </tr>
  <tr> <th class="right">$prompt_public:</th>           <td class="left">##publicly_readable.checkbox##</td> </tr>
  <tr> <th class="right">$prompt_calendar:</th>         <td class="left">##is_calendar.checkbox##</td> </tr>
  <tr> <th class="right">$prompt_addressbook:</th>      <td class="left">##is_addressbook.checkbox##</td> </tr>
  <tr> <th class="right">$prompt_privileges:</th><td class="left">##use_default_privs.checkbox## &nbsp; &nbsp; &nbsp;
  <div id="privileges_settings">
-<input type="button" value="$btn_all" class="submit" title="$btn_all_title" onclick="toggle_privileges('default_privileges', 'all', 'form_editor_1');">
-<input type="button" value="$btn_rw" class="submit" title="$btn_rw_title"
- onclick="toggle_privileges('default_privileges', 'read', 'write-properties', 'write-content', 'bind', 'unbind', 'read-free-busy',
-                            'read-current-user-privilege-set', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy',
-                            'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
-<input type="button" value="$btn_read" class="submit" title="$btn_read_title"
- onclick="toggle_privileges('default_privileges', 'read', 'read-free-busy', 'schedule-query-freebusy', 'read-current-user-privilege-set' );">
-<input type="button" value="$btn_fb" class="submit" title="$btn_fb_title"
- onclick="toggle_privileges('default_privileges', 'read-free-busy', 'schedule-query-freebusy' );">
-<input type="button" value="$btn_sd" class="submit" title="$btn_sd_title"
- onclick="toggle_privileges('default_privileges', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy' );">
-<input type="button" value="$btn_ss" class="submit" title="$btn_ss_title"
- onclick="toggle_privileges('default_privileges', 'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
-<br>$privileges_set</div></td> </tr>
+  $privileges_row
+ </div></td> </tr>
  <tr> <th class="right">$prompt_timezone:</th>         <td class="left">##timezone.select##</td> </tr>
  <tr> <th class="right">$prompt_schedule_transp:</th>  <td class="left">##schedule_transp.select##</td> </tr>
  <tr> <th class="right">$prompt_description:</th>      <td class="left">##description.textarea.78x6##</td> </tr>
- <tr> <th class="right"></th>                   <td class="left" colspan="2">##submit##</td> </tr>
+ $submit_row
 </table>
 </form>
 <script language="javascript">
@@ -367,7 +379,7 @@ toggle_visible('fld_use_default_privs','!privileges_settings');
 
 EOTEMPLATE;
 
- 
+
 
 $editor->SetTemplate( $template );
 $page_elements[] = $editor;
@@ -405,7 +417,7 @@ if ( $editor->Available() ) {
     }
   }
 
-  function edit_grant_row( $row_data ) {
+  function edit_grant_row_collection( $row_data ) {
     global $grantrow, $id, $privilege_xlate, $privilege_names;
     global $btn_all, $btn_all_title, $btn_rw, $btn_rw_title, $btn_read, $btn_read_title;
     global $btn_fb, $btn_fb_title, $btn_sd, $btn_sd_title, $btn_ss, $btn_ss_title;
@@ -441,10 +453,6 @@ if ( $editor->Available() ) {
  onclick="toggle_privileges('grant_privileges', 'read', 'read-free-busy', 'schedule-query-freebusy', 'read-current-user-privilege-set' );">
 <input type="button" value="$btn_fb" class="submit" title="$btn_fb_title"
  onclick="toggle_privileges('grant_privileges', 'read-free-busy', 'schedule-query-freebusy' );">
-<input type="button" value="$btn_sd" class="submit" title="$btn_sd_title"
- onclick="toggle_privileges('grant_privileges', 'schedule-deliver-invite', 'schedule-deliver-reply', 'schedule-query-freebusy' );">
-<input type="button" value="$btn_ss" class="submit" title="$btn_ss_title"
- onclick="toggle_privileges('grant_privileges', 'schedule-send-invite', 'schedule-send-reply', 'schedule-send-freebusy' );">
 <br>$privileges_set
   <td class="center">##$submit_label.submit##</td>
 </form>
@@ -464,12 +472,12 @@ EOTEMPLATE;
   $browser->AddHidden( 'principal_link', "'<a href=\"$rowurl' || to_principal || '\">' || to_principal || '</a>'" );
   $browser->AddHidden( 'grant_privileges', 'privileges' );
   $browser->AddColumn( 'displayname', translate('Display Name') );
-  $browser->AddColumn( 'privs', translate('Privileges'), '', '', 'privileges', '', '', 'privilege_format_function' );
+  $browser->AddColumn( 'privs', translate('Privileges'), '', '', 'privileges', '', '', 'collection_privilege_format_function' );
   $browser->AddColumn( 'members', translate('Has Members'), '', '', 'has_members_list(principal_id)' );
 
   if ( $can_write_collection ) {
-    $del_link  = '<a href="'.$c->base_url.'/admin.php?action=edit&t=collection&id='.$id.'&delete_grant=##to_principal##" class="submit">'.translate('Revoke').'</a>';
-    $edit_link  = '<a href="'.$c->base_url.'/admin.php?action=edit&t=collection&id='.$id.'&edit_grant=##to_principal##" class="submit">'.translate('Edit').'</a>';
+    $del_link  = '<a href="'.$c->base_url.'/admin.php?action=edit&t=collection&id='.$id.'&delete_grant=##to_principal##" class="submit" title="">'.translate('Revoke').'</a>';
+    $edit_link  = '<a href="'.$c->base_url.'/admin.php?action=edit&t=collection&id='.$id.'&edit_grant=##to_principal##" class="submit" title="">'.translate('Edit').'</a>';
     $browser->AddColumn( 'action', translate('Action'), 'center', '', "'$edit_link&nbsp;$del_link'" );
   }
 
@@ -489,11 +497,12 @@ EOTEMPLATE;
 
   if ( $can_write_collection ) {
     if ( isset($_GET['edit_grant']) ) {
-      $browser->MatchedRow('to_principal', $_GET['edit_grant'], 'edit_grant_row');
+      $browser->MatchedRow('to_principal', $_GET['edit_grant'], 'edit_grant_row_collection');
     }
     else {
+      $browser->ExtraRowFormat( '<tr class="r%d">', '</tr>', '#even' );
       $extra_row = array( 'to_principal' => -1 );
-      $browser->MatchedRow('to_principal', -1, 'edit_grant_row');
+      $browser->MatchedRow('to_principal', -1, 'edit_grant_row_collection');
       $extra_row = (object) $extra_row;
       $browser->AddRow($extra_row);
     }
@@ -502,12 +511,16 @@ EOTEMPLATE;
 
   $browser = new Browser(translate('Access Tickets'));
   $browser->AddHidden( 'dav_owner_id' );
-  $browser->AddColumn( 'ticket_id', translate('Ticket ID'), '', '' );
+  if ($can_write_collection) {
+    $browser->AddColumn( 'ticket_id', translate('Ticket ID'), '', '' );
+  }
   $browser->AddColumn( 'target', translate('Target'), '', '<td style="white-space:nowrap;">%s</td>', "'".$c->base_url.'/caldav.php'."' ||COALESCE(d.dav_name,c.dav_name)" );
   $browser->AddColumn( 'expiry', translate('Expires'), '', '', 'TO_CHAR(expires,\'YYYYMMDD"T"HH:MI:SS\')');
   $browser->AddColumn( 'privs', translate('Privileges'), '', '', "privileges_list(privileges)" );
-  $delurl = $c->base_url . '/admin.php?action=edit&t=principal&id=##dav_owner_id##&ticket_id=##URL:ticket_id##&subaction=delete_ticket';
-  $browser->AddColumn( 'delete', translate('Action'), 'center', '', "'<a class=\"submit\" href=\"$delurl\">".translate('Delete')."</a>'" );
+  if ($can_write_collection) {
+    $delurl = $c->base_url . '/admin.php?action=edit&t=principal&id=##dav_owner_id##&ticket_id=##URL:ticket_id##&subaction=delete_ticket';
+    $browser->AddColumn( 'delete', translate('Action'), 'center', '', "'<a class=\"submit\" href=\"$delurl\">".translate('Delete')."</a>'" );
+  }
 
   $browser->SetOrdering( 'target', 'A' );
 
@@ -519,15 +532,15 @@ EOTEMPLATE;
   $browser->DoQuery();
   $page_elements[] = $browser;
 
-  
+
 /**
  bind_id          | bigint | not null default nextval('dav_id_seq'::regclass)
- bound_source_id  | bigint | 
- access_ticket_id | text   | 
+ bound_source_id  | bigint |
+ access_ticket_id | text   |
  dav_owner_id     | bigint | not null
  parent_container | text   | not null
  dav_name         | text   | not null
- dav_displayname  | text   | 
+ dav_displayname  | text   |
  */
 
   $browser = new Browser(translate('Bindings to this Collection'));
@@ -536,8 +549,10 @@ EOTEMPLATE;
   $browser->AddColumn( 'bound_as', translate('Bound As'), '', '<td style="white-space:nowrap;">%s</td>', 'b.dav_name' );
   $browser->AddColumn( 'access_ticket_id', translate('Ticket ID'), '', '' );
   $browser->AddColumn( 'privs', translate('Privileges'), '', '', "privileges_list(privileges)" );
-  $delurl = $c->base_url . '/admin.php?action=edit&t=principal&id=##dav_owner_id##&bind_id=##URL:bind_id##&subaction=delete_binding';
-  $browser->AddColumn( 'delete', translate('Action'), 'center', '', "'<a class=\"submit\" href=\"$delurl\">".translate('Delete')."</a>'" );
+  if ( $session->AllowedTo('Admin') ) {
+    $delurl = $c->base_url . '/admin.php?action=edit&t=principal&id=##dav_owner_id##&bind_id=##URL:bind_id##&subaction=delete_binding';
+    $browser->AddColumn( 'delete', translate('Action'), 'center', '', "'<a class=\"submit\" href=\"$delurl\">".translate('Delete')."</a>'" );
+  }
 
   $browser->SetOrdering( 'target', 'A' );
 
